# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.compute.v1 import instance_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2
from yandex.cloud.compute.v1 import instance_service_pb2 as yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class InstanceServiceStub(object):
    """A set of methods for managing Instance resources.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Get',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/List',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Create',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Update',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Delete',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateMetadata = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/UpdateMetadata',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.GetSerialPortOutput = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/GetSerialPortOutput',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.FromString,
                )
        self.Stop = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Stop',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Start = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Start',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Restart = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/Restart',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AttachDisk = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AttachDisk',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DetachDisk = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/DetachDisk',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AttachFilesystem = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AttachFilesystem',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.DetachFilesystem = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/DetachFilesystem',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.AddOneToOneNat = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/AddOneToOneNat',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.RemoveOneToOneNat = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/RemoveOneToOneNat',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.UpdateNetworkInterface = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/UpdateNetworkInterface',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.ListOperations = channel.unary_unary(
                '/yandex.cloud.compute.v1.InstanceService/ListOperations',
                request_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.FromString,
                )


class InstanceServiceServicer(object):
    """A set of methods for managing Instance resources.
    """

    def Get(self, request, context):
        """Returns the specified Instance resource.

        To get the list of available Instance resources, make a [List] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Retrieves the list of Instance resources in the specified folder.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates an instance in the specified folder.
        Method starts an asynchronous operation that can be cancelled while it is in progress.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateMetadata(self, request, context):
        """Updates the metadata of the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSerialPortOutput(self, request, context):
        """Returns the serial port output of the specified Instance resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Stop(self, request, context):
        """Stops the running instance.

        You can start the instance later using the [InstanceService.Start] method.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Start(self, request, context):
        """Starts the stopped instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Restart(self, request, context):
        """Restarts the running instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachDisk(self, request, context):
        """Attaches the disk to the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachDisk(self, request, context):
        """Detaches the disk from the instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AttachFilesystem(self, request, context):
        """Attaches the filesystem to the instance.

        The instance and the filesystem must reside in the same availability zone.

        To attach a filesystem, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.

        To use the instance with an attached filesystem, the latter must be mounted.
        For details, see [documentation](/docs/compute/operations/filesystem/attach-to-vm).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DetachFilesystem(self, request, context):
        """Detaches the filesystem from the instance.

        To detach a filesystem, the instance must have a `STOPPED` status ([Instance.status]).
        To check the instance status, make a [InstanceService.Get] request.
        To stop the running instance, make a [InstanceService.Stop] request.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddOneToOneNat(self, request, context):
        """Enables One-to-one NAT on the network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RemoveOneToOneNat(self, request, context):
        """Removes One-to-one NAT from the network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNetworkInterface(self, request, context):
        """Updates the specified instance network interface.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOperations(self, request, context):
        """Lists operations for the specified instance.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_InstanceServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateMetadata': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateMetadata,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'GetSerialPortOutput': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSerialPortOutput,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.SerializeToString,
            ),
            'Stop': grpc.unary_unary_rpc_method_handler(
                    servicer.Stop,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Start': grpc.unary_unary_rpc_method_handler(
                    servicer.Start,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Restart': grpc.unary_unary_rpc_method_handler(
                    servicer.Restart,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachDisk': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachDisk,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachDisk': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachDisk,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AttachFilesystem': grpc.unary_unary_rpc_method_handler(
                    servicer.AttachFilesystem,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'DetachFilesystem': grpc.unary_unary_rpc_method_handler(
                    servicer.DetachFilesystem,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'AddOneToOneNat': grpc.unary_unary_rpc_method_handler(
                    servicer.AddOneToOneNat,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'RemoveOneToOneNat': grpc.unary_unary_rpc_method_handler(
                    servicer.RemoveOneToOneNat,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'UpdateNetworkInterface': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNetworkInterface,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'ListOperations': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOperations,
                    request_deserializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.compute.v1.InstanceService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class InstanceService(object):
    """A set of methods for managing Instance resources.
    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Get',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__pb2.Instance.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/List',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstancesResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Create',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.CreateInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Update',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Delete',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DeleteInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateMetadata(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/UpdateMetadata',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceMetadataRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSerialPortOutput(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/GetSerialPortOutput',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.GetInstanceSerialPortOutputResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Stop(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Stop',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StopInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Start(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Start',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.StartInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Restart(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/Restart',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RestartInstanceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachDisk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/AttachDisk',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachDisk(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/DetachDisk',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceDiskRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AttachFilesystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/AttachFilesystem',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AttachInstanceFilesystemRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DetachFilesystem(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/DetachFilesystem',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.DetachInstanceFilesystemRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddOneToOneNat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/AddOneToOneNat',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.AddInstanceOneToOneNatRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RemoveOneToOneNat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/RemoveOneToOneNat',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.RemoveInstanceOneToOneNatRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNetworkInterface(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/UpdateNetworkInterface',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.UpdateInstanceNetworkInterfaceRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListOperations(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.compute.v1.InstanceService/ListOperations',
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsRequest.SerializeToString,
            yandex_dot_cloud_dot_compute_dot_v1_dot_instance__service__pb2.ListInstanceOperationsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/compute/v1/zone.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/compute/v1/zone.proto',
  package='yandex.cloud.compute.v1',
  syntax='proto3',
  serialized_options=b'\n\033yandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;compute',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\"yandex/cloud/compute/v1/zone.proto\x12\x17yandex.cloud.compute.v1\"\x8f\x01\n\x04Zone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tregion_id\x18\x02 \x01(\t\x12\x34\n\x06status\x18\x03 \x01(\x0e\x32$.yandex.cloud.compute.v1.Zone.Status\"2\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x08\n\x04\x44OWN\x10\x02\x42\x62\n\x1byandex.cloud.api.compute.v1ZCgithub.com/yandex-cloud/go-genproto/yandex/cloud/compute/v1;computeb\x06proto3'
)



_ZONE_STATUS = _descriptor.EnumDescriptor(
  name='Status',
  full_name='yandex.cloud.compute.v1.Zone.Status',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DOWN', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=157,
  serialized_end=207,
)
_sym_db.RegisterEnumDescriptor(_ZONE_STATUS)


_ZONE = _descriptor.Descriptor(
  name='Zone',
  full_name='yandex.cloud.compute.v1.Zone',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yandex.cloud.compute.v1.Zone.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_id', full_name='yandex.cloud.compute.v1.Zone.region_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='yandex.cloud.compute.v1.Zone.status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ZONE_STATUS,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=207,
)

_ZONE.fields_by_name['status'].enum_type = _ZONE_STATUS
_ZONE_STATUS.containing_type = _ZONE
DESCRIPTOR.message_types_by_name['Zone'] = _ZONE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Zone = _reflection.GeneratedProtocolMessageType('Zone', (_message.Message,), {
  'DESCRIPTOR' : _ZONE,
  '__module__' : 'yandex.cloud.compute.v1.zone_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.compute.v1.Zone)
  })
_sym_db.RegisterMessage(Zone)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from yandex.cloud.cdn.v1 import origin_group_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2
from yandex.cloud.cdn.v1 import origin_group_service_pb2 as yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2


class OriginGroupServiceStub(object):
    """
    Origin Groups management service.

    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Get = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginGroupService/Get',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.GetOriginGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2.OriginGroup.FromString,
                )
        self.List = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginGroupService/List',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsResponse.FromString,
                )
        self.Create = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginGroupService/Create',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.CreateOriginGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Update = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginGroupService/Update',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.UpdateOriginGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )
        self.Delete = channel.unary_unary(
                '/yandex.cloud.cdn.v1.OriginGroupService/Delete',
                request_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.DeleteOriginGroupRequest.SerializeToString,
                response_deserializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
                )


class OriginGroupServiceServicer(object):
    """
    Origin Groups management service.

    """

    def Get(self, request, context):
        """Gets origin group with specified origin group id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def List(self, request, context):
        """Lists origins of origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Create(self, request, context):
        """Creates origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Update(self, request, context):
        """Updates origin group.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Delete(self, request, context):
        """Deletes origin group with specified origin group id.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_OriginGroupServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Get': grpc.unary_unary_rpc_method_handler(
                    servicer.Get,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.GetOriginGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2.OriginGroup.SerializeToString,
            ),
            'List': grpc.unary_unary_rpc_method_handler(
                    servicer.List,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsResponse.SerializeToString,
            ),
            'Create': grpc.unary_unary_rpc_method_handler(
                    servicer.Create,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.CreateOriginGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Update': grpc.unary_unary_rpc_method_handler(
                    servicer.Update,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.UpdateOriginGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
            'Delete': grpc.unary_unary_rpc_method_handler(
                    servicer.Delete,
                    request_deserializer=yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.DeleteOriginGroupRequest.FromString,
                    response_serializer=yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'yandex.cloud.cdn.v1.OriginGroupService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class OriginGroupService(object):
    """
    Origin Groups management service.

    """

    @staticmethod
    def Get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginGroupService/Get',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.GetOriginGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__pb2.OriginGroup.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def List(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginGroupService/List',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsRequest.SerializeToString,
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.ListOriginGroupsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginGroupService/Create',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.CreateOriginGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginGroupService/Update',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.UpdateOriginGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/yandex.cloud.cdn.v1.OriginGroupService/Delete',
            yandex_dot_cloud_dot_cdn_dot_v1_dot_origin__group__service__pb2.DeleteOriginGroupRequest.SerializeToString,
            yandex_dot_cloud_dot_operation_dot_operation__pb2.Operation.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/apploadbalancer/v1/backend_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud.apploadbalancer.v1 import backend_group_pb2 as yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yandex/cloud/apploadbalancer/v1/backend_group_service.proto',
  package='yandex.cloud.apploadbalancer.v1',
  syntax='proto3',
  serialized_options=b'\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancer',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n;yandex/cloud/apploadbalancer/v1/backend_group_service.proto\x12\x1fyandex.cloud.apploadbalancer.v1\x1a\x1cgoogle/api/annotations.proto\x1a google/protobuf/field_mask.proto\x1a yandex/cloud/api/operation.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x33yandex/cloud/apploadbalancer/v1/backend_group.proto\x1a\x1dyandex/cloud/validation.proto\"8\n\x16GetBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"\x8d\x01\n\x18ListBackendGroupsRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\x12\x1a\n\x06\x66ilter\x18\x04 \x01(\tB\n\x8a\xc8\x31\x06<=1000\"{\n\x19ListBackendGroupsResponse\x12\x45\n\x0e\x62\x61\x63kend_groups\x18\x01 \x03(\x0b\x32-.yandex.cloud.apploadbalancer.v1.BackendGroup\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\";\n\x19\x44\x65leteBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\"6\n\x1a\x44\x65leteBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xaa\x04\n\x19UpdateBackendGroupRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12\x34\n\x04name\x18\x03 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x04 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x05 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x41\n\x04http\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x07 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"6\n\x1aUpdateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\xec\x03\n\x19\x43reateBackendGroupRequest\x12\x17\n\tfolder_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x34\n\x04name\x18\x02 \x01(\tB&\xf2\xc7\x31\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?\x12\x1e\n\x0b\x64\x65scription\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=256\x12\x9f\x01\n\x06labels\x18\x04 \x03(\x0b\x32\x46.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntryBG\x82\xc8\x31\x04<=64\x8a\xc8\x31\x04<=63\xf2\xc7\x31\x0f[-_./\\@0-9a-z]*\xb2\xc8\x31\x06\x1a\x04\x31-63\xb2\xc8\x31\x16\x12\x14[a-z][-_./\\@0-9a-z]*\x12\x41\n\x04http\x18\x05 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.HttpBackendGroupH\x00\x12\x41\n\x04grpc\x18\x06 \x01(\x0b\x32\x31.yandex.cloud.apploadbalancer.v1.GrpcBackendGroupH\x00\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\t\n\x07\x62\x61\x63kend\"6\n\x1a\x43reateBackendGroupMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\"\x82\x02\n\x11\x41\x64\x64\x42\x61\x63kendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12<\n\x04http\x18\x02 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"D\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\xb6\x02\n\x14UpdateBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\x12<\n\x04http\x18\x03 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.HttpBackendH\x00\x12<\n\x04grpc\x18\x04 \x01(\x0b\x32,.yandex.cloud.apploadbalancer.v1.GrpcBackendH\x00\x12@\n\x06stream\x18\x05 \x01(\x0b\x32..yandex.cloud.apploadbalancer.v1.StreamBackendH\x00\x42\x0f\n\x07\x62\x61\x63kend\x12\x04\xc0\xc1\x31\x01\"G\n\x15UpdateBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"R\n\x14RemoveBackendRequest\x12\x1e\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x04\xe8\xc7\x31\x01\x12\x1a\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\tB\x04\xe8\xc7\x31\x01\"G\n\x15RemoveBackendMetadata\x12\x18\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\t\x12\x14\n\x0c\x62\x61\x63kend_name\x18\x02 \x01(\t\"\x89\x01\n!ListBackendGroupOperationsRequest\x12&\n\x10\x62\x61\x63kend_group_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06<=1000\x12\x1d\n\npage_token\x18\x03 \x01(\tB\t\x8a\xc8\x31\x05<=100\"t\n\"ListBackendGroupOperationsResponse\x12\x35\n\noperations\x18\x01 \x03(\x0b\x32!.yandex.cloud.operation.Operation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\xf1\x0e\n\x13\x42\x61\x63kendGroupService\x12\xab\x01\n\x03Get\x12\x37.yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest\x1a-.yandex.cloud.apploadbalancer.v1.BackendGroup\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/apploadbalancer/v1/backendGroups/{backend_group_id}\x12\xa8\x01\n\x04List\x12\x39.yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest\x1a:.yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse\")\x82\xd3\xe4\x93\x02#\x12!/apploadbalancer/v1/backendGroups\x12\xc3\x01\n\x06\x43reate\x12:.yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"Z\x82\xd3\xe4\x93\x02&\"!/apploadbalancer/v1/backendGroups:\x01*\xb2\xd2**\n\x1a\x43reateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x12\xd6\x01\n\x06Update\x12:.yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"m\x82\xd3\xe4\x93\x02\x39\x32\x34/apploadbalancer/v1/backendGroups/{backend_group_id}:\x01*\xb2\xd2**\n\x1aUpdateBackendGroupMetadata\x12\x0c\x42\x61\x63kendGroup\x12\xdc\x01\n\x06\x44\x65lete\x12:.yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest\x1a!.yandex.cloud.operation.Operation\"s\x82\xd3\xe4\x93\x02\x36*4/apploadbalancer/v1/backendGroups/{backend_group_id}\xb2\xd2*3\n\x1a\x44\x65leteBackendGroupMetadata\x12\x15google.protobuf.Empty\x12\xd5\x01\n\nAddBackend\x12\x32.yandex.cloud.apploadbalancer.v1.AddBackendRequest\x1a!.yandex.cloud.operation.Operation\"p\x82\xd3\xe4\x93\x02\x44\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\x01*\xb2\xd2*\"\n\x12\x41\x64\x64\x42\x61\x63kendMetadata\x12\x0c\x42\x61\x63kendGroup\x12\xe1\x01\n\rRemoveBackend\x12\x35.yandex.cloud.apploadbalancer.v1.RemoveBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\x01*\xb2\xd2*%\n\x15RemoveBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x12\xe1\x01\n\rUpdateBackend\x12\x35.yandex.cloud.apploadbalancer.v1.UpdateBackendRequest\x1a!.yandex.cloud.operation.Operation\"v\x82\xd3\xe4\x93\x02G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\x01*\xb2\xd2*%\n\x15UpdateBackendMetadata\x12\x0c\x42\x61\x63kendGroup\x12\xe2\x01\n\x0eListOperations\x12\x42.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest\x1a\x43.yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/apploadbalancer/v1/backendGroups/{backend_group_id}/operationsBz\n#yandex.cloud.api.apploadbalancer.v1ZSgithub.com/yandex-cloud/go-genproto/yandex/cloud/apploadbalancer/v1;apploadbalancerb\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,yandex_dot_cloud_dot_api_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_operation_dot_operation__pb2.DESCRIPTOR,yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2.DESCRIPTOR,yandex_dot_cloud_dot_validation__pb2.DESCRIPTOR,])




_GETBACKENDGROUPREQUEST = _descriptor.Descriptor(
  name='GetBackendGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=318,
  serialized_end=374,
)


_LISTBACKENDGROUPSREQUEST = _descriptor.Descriptor(
  name='ListBackendGroupsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\0060-1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='filter', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest.filter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=377,
  serialized_end=518,
)


_LISTBACKENDGROUPSRESPONSE = _descriptor.Descriptor(
  name='ListBackendGroupsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_groups', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse.backend_groups', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=643,
)


_DELETEBACKENDGROUPREQUEST = _descriptor.Descriptor(
  name='DeleteBackendGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=645,
  serialized_end=704,
)


_DELETEBACKENDGROUPMETADATA = _descriptor.Descriptor(
  name='DeleteBackendGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.DeleteBackendGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.DeleteBackendGroupMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=706,
  serialized_end=760,
)


_UPDATEBACKENDGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1300,
)

_UPDATEBACKENDGROUPREQUEST = _descriptor.Descriptor(
  name='UpdateBackendGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.labels', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.http', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.grpc', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_UPDATEBACKENDGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.backend',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=763,
  serialized_end=1317,
)


_UPDATEBACKENDGROUPMETADATA = _descriptor.Descriptor(
  name='UpdateBackendGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendGroupMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1319,
  serialized_end=1373,
)


_CREATEBACKENDGROUPREQUEST_LABELSENTRY = _descriptor.Descriptor(
  name='LabelsEntry',
  full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1255,
  serialized_end=1300,
)

_CREATEBACKENDGROUPREQUEST = _descriptor.Descriptor(
  name='CreateBackendGroupRequest',
  full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='folder_id', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.folder_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\3071\"([a-z]([-a-z0-9]{0,61}[a-z0-9])?)?', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='description', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=256', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='labels', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.labels', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\202\3101\004<=64\212\3101\004<=63\362\3071\017[-_./\\@0-9a-z]*\262\3101\006\032\0041-63\262\3101\026\022\024[a-z][-_./\\@0-9a-z]*', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.http', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.grpc', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_CREATEBACKENDGROUPREQUEST_LABELSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.backend',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1376,
  serialized_end=1868,
)


_CREATEBACKENDGROUPMETADATA = _descriptor.Descriptor(
  name='CreateBackendGroupMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.CreateBackendGroupMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1870,
  serialized_end=1924,
)


_ADDBACKENDREQUEST = _descriptor.Descriptor(
  name='AddBackendRequest',
  full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest.http', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest.grpc', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest.stream', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend', full_name='yandex.cloud.apploadbalancer.v1.AddBackendRequest.backend',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=1927,
  serialized_end=2185,
)


_ADDBACKENDMETADATA = _descriptor.Descriptor(
  name='AddBackendMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.AddBackendMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.AddBackendMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_name', full_name='yandex.cloud.apploadbalancer.v1.AddBackendMetadata.backend_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2187,
  serialized_end=2255,
)


_UPDATEBACKENDREQUEST = _descriptor.Descriptor(
  name='UpdateBackendRequest',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='update_mask', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.update_mask', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='http', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.http', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='grpc', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.grpc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.stream', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='backend', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendRequest.backend',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[], serialized_options=b'\300\3011\001'),
  ],
  serialized_start=2258,
  serialized_end=2568,
)


_UPDATEBACKENDMETADATA = _descriptor.Descriptor(
  name='UpdateBackendMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_name', full_name='yandex.cloud.apploadbalancer.v1.UpdateBackendMetadata.backend_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2570,
  serialized_end=2641,
)


_REMOVEBACKENDREQUEST = _descriptor.Descriptor(
  name='RemoveBackendRequest',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendRequest.backend_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2643,
  serialized_end=2725,
)


_REMOVEBACKENDMETADATA = _descriptor.Descriptor(
  name='RemoveBackendMetadata',
  full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendMetadata.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='backend_name', full_name='yandex.cloud.apploadbalancer.v1.RemoveBackendMetadata.backend_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2727,
  serialized_end=2798,
)


_LISTBACKENDGROUPOPERATIONSREQUEST = _descriptor.Descriptor(
  name='ListBackendGroupOperationsRequest',
  full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='backend_group_id', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest.backend_group_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\350\3071\001\212\3101\004<=50', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_size', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest.page_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\372\3071\006<=1000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='page_token', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest.page_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\212\3101\005<=100', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2801,
  serialized_end=2938,
)


_LISTBACKENDGROUPOPERATIONSRESPONSE = _descriptor.Descriptor(
  name='ListBackendGroupOperationsResponse',
  full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operations', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse.operations', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_page_token', full_name='yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse.next_page_token', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2940,
  serialized_end=3056,
)

_LISTBACKENDGROUPSRESPONSE.fields_by_name['backend_groups'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._BACKENDGROUP
_UPDATEBACKENDGROUPREQUEST_LABELSENTRY.containing_type = _UPDATEBACKENDGROUPREQUEST
_UPDATEBACKENDGROUPREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEBACKENDGROUPREQUEST.fields_by_name['labels'].message_type = _UPDATEBACKENDGROUPREQUEST_LABELSENTRY
_UPDATEBACKENDGROUPREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._HTTPBACKENDGROUP
_UPDATEBACKENDGROUPREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._GRPCBACKENDGROUP
_UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend'].fields.append(
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['http'])
_UPDATEBACKENDGROUPREQUEST.fields_by_name['http'].containing_oneof = _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']
_UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend'].fields.append(
  _UPDATEBACKENDGROUPREQUEST.fields_by_name['grpc'])
_UPDATEBACKENDGROUPREQUEST.fields_by_name['grpc'].containing_oneof = _UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']
_CREATEBACKENDGROUPREQUEST_LABELSENTRY.containing_type = _CREATEBACKENDGROUPREQUEST
_CREATEBACKENDGROUPREQUEST.fields_by_name['labels'].message_type = _CREATEBACKENDGROUPREQUEST_LABELSENTRY
_CREATEBACKENDGROUPREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._HTTPBACKENDGROUP
_CREATEBACKENDGROUPREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._GRPCBACKENDGROUP
_CREATEBACKENDGROUPREQUEST.oneofs_by_name['backend'].fields.append(
  _CREATEBACKENDGROUPREQUEST.fields_by_name['http'])
_CREATEBACKENDGROUPREQUEST.fields_by_name['http'].containing_oneof = _CREATEBACKENDGROUPREQUEST.oneofs_by_name['backend']
_CREATEBACKENDGROUPREQUEST.oneofs_by_name['backend'].fields.append(
  _CREATEBACKENDGROUPREQUEST.fields_by_name['grpc'])
_CREATEBACKENDGROUPREQUEST.fields_by_name['grpc'].containing_oneof = _CREATEBACKENDGROUPREQUEST.oneofs_by_name['backend']
_ADDBACKENDREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._HTTPBACKEND
_ADDBACKENDREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._GRPCBACKEND
_ADDBACKENDREQUEST.fields_by_name['stream'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._STREAMBACKEND
_ADDBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _ADDBACKENDREQUEST.fields_by_name['http'])
_ADDBACKENDREQUEST.fields_by_name['http'].containing_oneof = _ADDBACKENDREQUEST.oneofs_by_name['backend']
_ADDBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _ADDBACKENDREQUEST.fields_by_name['grpc'])
_ADDBACKENDREQUEST.fields_by_name['grpc'].containing_oneof = _ADDBACKENDREQUEST.oneofs_by_name['backend']
_ADDBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _ADDBACKENDREQUEST.fields_by_name['stream'])
_ADDBACKENDREQUEST.fields_by_name['stream'].containing_oneof = _ADDBACKENDREQUEST.oneofs_by_name['backend']
_UPDATEBACKENDREQUEST.fields_by_name['update_mask'].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_UPDATEBACKENDREQUEST.fields_by_name['http'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._HTTPBACKEND
_UPDATEBACKENDREQUEST.fields_by_name['grpc'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._GRPCBACKEND
_UPDATEBACKENDREQUEST.fields_by_name['stream'].message_type = yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._STREAMBACKEND
_UPDATEBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _UPDATEBACKENDREQUEST.fields_by_name['http'])
_UPDATEBACKENDREQUEST.fields_by_name['http'].containing_oneof = _UPDATEBACKENDREQUEST.oneofs_by_name['backend']
_UPDATEBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _UPDATEBACKENDREQUEST.fields_by_name['grpc'])
_UPDATEBACKENDREQUEST.fields_by_name['grpc'].containing_oneof = _UPDATEBACKENDREQUEST.oneofs_by_name['backend']
_UPDATEBACKENDREQUEST.oneofs_by_name['backend'].fields.append(
  _UPDATEBACKENDREQUEST.fields_by_name['stream'])
_UPDATEBACKENDREQUEST.fields_by_name['stream'].containing_oneof = _UPDATEBACKENDREQUEST.oneofs_by_name['backend']
_LISTBACKENDGROUPOPERATIONSRESPONSE.fields_by_name['operations'].message_type = yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION
DESCRIPTOR.message_types_by_name['GetBackendGroupRequest'] = _GETBACKENDGROUPREQUEST
DESCRIPTOR.message_types_by_name['ListBackendGroupsRequest'] = _LISTBACKENDGROUPSREQUEST
DESCRIPTOR.message_types_by_name['ListBackendGroupsResponse'] = _LISTBACKENDGROUPSRESPONSE
DESCRIPTOR.message_types_by_name['DeleteBackendGroupRequest'] = _DELETEBACKENDGROUPREQUEST
DESCRIPTOR.message_types_by_name['DeleteBackendGroupMetadata'] = _DELETEBACKENDGROUPMETADATA
DESCRIPTOR.message_types_by_name['UpdateBackendGroupRequest'] = _UPDATEBACKENDGROUPREQUEST
DESCRIPTOR.message_types_by_name['UpdateBackendGroupMetadata'] = _UPDATEBACKENDGROUPMETADATA
DESCRIPTOR.message_types_by_name['CreateBackendGroupRequest'] = _CREATEBACKENDGROUPREQUEST
DESCRIPTOR.message_types_by_name['CreateBackendGroupMetadata'] = _CREATEBACKENDGROUPMETADATA
DESCRIPTOR.message_types_by_name['AddBackendRequest'] = _ADDBACKENDREQUEST
DESCRIPTOR.message_types_by_name['AddBackendMetadata'] = _ADDBACKENDMETADATA
DESCRIPTOR.message_types_by_name['UpdateBackendRequest'] = _UPDATEBACKENDREQUEST
DESCRIPTOR.message_types_by_name['UpdateBackendMetadata'] = _UPDATEBACKENDMETADATA
DESCRIPTOR.message_types_by_name['RemoveBackendRequest'] = _REMOVEBACKENDREQUEST
DESCRIPTOR.message_types_by_name['RemoveBackendMetadata'] = _REMOVEBACKENDMETADATA
DESCRIPTOR.message_types_by_name['ListBackendGroupOperationsRequest'] = _LISTBACKENDGROUPOPERATIONSREQUEST
DESCRIPTOR.message_types_by_name['ListBackendGroupOperationsResponse'] = _LISTBACKENDGROUPOPERATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetBackendGroupRequest = _reflection.GeneratedProtocolMessageType('GetBackendGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETBACKENDGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.GetBackendGroupRequest)
  })
_sym_db.RegisterMessage(GetBackendGroupRequest)

ListBackendGroupsRequest = _reflection.GeneratedProtocolMessageType('ListBackendGroupsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBACKENDGROUPSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListBackendGroupsRequest)
  })
_sym_db.RegisterMessage(ListBackendGroupsRequest)

ListBackendGroupsResponse = _reflection.GeneratedProtocolMessageType('ListBackendGroupsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBACKENDGROUPSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListBackendGroupsResponse)
  })
_sym_db.RegisterMessage(ListBackendGroupsResponse)

DeleteBackendGroupRequest = _reflection.GeneratedProtocolMessageType('DeleteBackendGroupRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBACKENDGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteBackendGroupRequest)
  })
_sym_db.RegisterMessage(DeleteBackendGroupRequest)

DeleteBackendGroupMetadata = _reflection.GeneratedProtocolMessageType('DeleteBackendGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _DELETEBACKENDGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.DeleteBackendGroupMetadata)
  })
_sym_db.RegisterMessage(DeleteBackendGroupMetadata)

UpdateBackendGroupRequest = _reflection.GeneratedProtocolMessageType('UpdateBackendGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEBACKENDGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEBACKENDGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateBackendGroupRequest)
  })
_sym_db.RegisterMessage(UpdateBackendGroupRequest)
_sym_db.RegisterMessage(UpdateBackendGroupRequest.LabelsEntry)

UpdateBackendGroupMetadata = _reflection.GeneratedProtocolMessageType('UpdateBackendGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBACKENDGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateBackendGroupMetadata)
  })
_sym_db.RegisterMessage(UpdateBackendGroupMetadata)

CreateBackendGroupRequest = _reflection.GeneratedProtocolMessageType('CreateBackendGroupRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEBACKENDGROUPREQUEST_LABELSENTRY,
    '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
    # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEBACKENDGROUPREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateBackendGroupRequest)
  })
_sym_db.RegisterMessage(CreateBackendGroupRequest)
_sym_db.RegisterMessage(CreateBackendGroupRequest.LabelsEntry)

CreateBackendGroupMetadata = _reflection.GeneratedProtocolMessageType('CreateBackendGroupMetadata', (_message.Message,), {
  'DESCRIPTOR' : _CREATEBACKENDGROUPMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.CreateBackendGroupMetadata)
  })
_sym_db.RegisterMessage(CreateBackendGroupMetadata)

AddBackendRequest = _reflection.GeneratedProtocolMessageType('AddBackendRequest', (_message.Message,), {
  'DESCRIPTOR' : _ADDBACKENDREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddBackendRequest)
  })
_sym_db.RegisterMessage(AddBackendRequest)

AddBackendMetadata = _reflection.GeneratedProtocolMessageType('AddBackendMetadata', (_message.Message,), {
  'DESCRIPTOR' : _ADDBACKENDMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.AddBackendMetadata)
  })
_sym_db.RegisterMessage(AddBackendMetadata)

UpdateBackendRequest = _reflection.GeneratedProtocolMessageType('UpdateBackendRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBACKENDREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateBackendRequest)
  })
_sym_db.RegisterMessage(UpdateBackendRequest)

UpdateBackendMetadata = _reflection.GeneratedProtocolMessageType('UpdateBackendMetadata', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEBACKENDMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.UpdateBackendMetadata)
  })
_sym_db.RegisterMessage(UpdateBackendMetadata)

RemoveBackendRequest = _reflection.GeneratedProtocolMessageType('RemoveBackendRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEBACKENDREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveBackendRequest)
  })
_sym_db.RegisterMessage(RemoveBackendRequest)

RemoveBackendMetadata = _reflection.GeneratedProtocolMessageType('RemoveBackendMetadata', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEBACKENDMETADATA,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.RemoveBackendMetadata)
  })
_sym_db.RegisterMessage(RemoveBackendMetadata)

ListBackendGroupOperationsRequest = _reflection.GeneratedProtocolMessageType('ListBackendGroupOperationsRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTBACKENDGROUPOPERATIONSREQUEST,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsRequest)
  })
_sym_db.RegisterMessage(ListBackendGroupOperationsRequest)

ListBackendGroupOperationsResponse = _reflection.GeneratedProtocolMessageType('ListBackendGroupOperationsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTBACKENDGROUPOPERATIONSRESPONSE,
  '__module__' : 'yandex.cloud.apploadbalancer.v1.backend_group_service_pb2'
  # @@protoc_insertion_point(class_scope:yandex.cloud.apploadbalancer.v1.ListBackendGroupOperationsResponse)
  })
_sym_db.RegisterMessage(ListBackendGroupOperationsResponse)


DESCRIPTOR._options = None
_GETBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
_LISTBACKENDGROUPSREQUEST.fields_by_name['folder_id']._options = None
_LISTBACKENDGROUPSREQUEST.fields_by_name['page_size']._options = None
_LISTBACKENDGROUPSREQUEST.fields_by_name['page_token']._options = None
_LISTBACKENDGROUPSREQUEST.fields_by_name['filter']._options = None
_DELETEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
_UPDATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
_UPDATEBACKENDGROUPREQUEST.oneofs_by_name['backend']._options = None
_UPDATEBACKENDGROUPREQUEST.fields_by_name['backend_group_id']._options = None
_UPDATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
_UPDATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
_UPDATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
_CREATEBACKENDGROUPREQUEST_LABELSENTRY._options = None
_CREATEBACKENDGROUPREQUEST.fields_by_name['folder_id']._options = None
_CREATEBACKENDGROUPREQUEST.fields_by_name['name']._options = None
_CREATEBACKENDGROUPREQUEST.fields_by_name['description']._options = None
_CREATEBACKENDGROUPREQUEST.fields_by_name['labels']._options = None
_ADDBACKENDREQUEST.oneofs_by_name['backend']._options = None
_ADDBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
_UPDATEBACKENDREQUEST.oneofs_by_name['backend']._options = None
_UPDATEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
_REMOVEBACKENDREQUEST.fields_by_name['backend_group_id']._options = None
_REMOVEBACKENDREQUEST.fields_by_name['backend_name']._options = None
_LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['backend_group_id']._options = None
_LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_size']._options = None
_LISTBACKENDGROUPOPERATIONSREQUEST.fields_by_name['page_token']._options = None

_BACKENDGROUPSERVICE = _descriptor.ServiceDescriptor(
  name='BackendGroupService',
  full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3059,
  serialized_end=4964,
  methods=[
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.Get',
    index=0,
    containing_service=None,
    input_type=_GETBACKENDGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_apploadbalancer_dot_v1_dot_backend__group__pb2._BACKENDGROUP,
    serialized_options=b'\202\323\344\223\0026\0224/apploadbalancer/v1/backendGroups/{backend_group_id}',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='List',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.List',
    index=1,
    containing_service=None,
    input_type=_LISTBACKENDGROUPSREQUEST,
    output_type=_LISTBACKENDGROUPSRESPONSE,
    serialized_options=b'\202\323\344\223\002#\022!/apploadbalancer/v1/backendGroups',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Create',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.Create',
    index=2,
    containing_service=None,
    input_type=_CREATEBACKENDGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002&\"!/apploadbalancer/v1/backendGroups:\001*\262\322**\n\032CreateBackendGroupMetadata\022\014BackendGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Update',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.Update',
    index=3,
    containing_service=None,
    input_type=_UPDATEBACKENDGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002924/apploadbalancer/v1/backendGroups/{backend_group_id}:\001*\262\322**\n\032UpdateBackendGroupMetadata\022\014BackendGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='Delete',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.Delete',
    index=4,
    containing_service=None,
    input_type=_DELETEBACKENDGROUPREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\0026*4/apploadbalancer/v1/backendGroups/{backend_group_id}\262\322*3\n\032DeleteBackendGroupMetadata\022\025google.protobuf.Empty',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='AddBackend',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.AddBackend',
    index=5,
    containing_service=None,
    input_type=_ADDBACKENDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002D\"?/apploadbalancer/v1/backendGroups/{backend_group_id}:addBackend:\001*\262\322*\"\n\022AddBackendMetadata\022\014BackendGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='RemoveBackend',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.RemoveBackend',
    index=6,
    containing_service=None,
    input_type=_REMOVEBACKENDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:removeBackend:\001*\262\322*%\n\025RemoveBackendMetadata\022\014BackendGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='UpdateBackend',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.UpdateBackend',
    index=7,
    containing_service=None,
    input_type=_UPDATEBACKENDREQUEST,
    output_type=yandex_dot_cloud_dot_operation_dot_operation__pb2._OPERATION,
    serialized_options=b'\202\323\344\223\002G\"B/apploadbalancer/v1/backendGroups/{backend_group_id}:updateBackend:\001*\262\322*%\n\025UpdateBackendMetadata\022\014BackendGroup',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='ListOperations',
    full_name='yandex.cloud.apploadbalancer.v1.BackendGroupService.ListOperations',
    index=8,
    containing_service=None,
    input_type=_LISTBACKENDGROUPOPERATIONSREQUEST,
    output_type=_LISTBACKENDGROUPOPERATIONSRESPONSE,
    serialized_options=b'\202\323\344\223\002A\022?/apploadbalancer/v1/backendGroups/{backend_group_id}/operations',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_BACKENDGROUPSERVICE)

DESCRIPTOR.services_by_name['BackendGroupService'] = _BACKENDGROUPSERVICE

# @@protoc_insertion_point(module_scope)
